class Account:
    def __init__(self, account_number, balance):
        self.account_number = account_number
        self.balance = balance

    def deposit(self, amount):
        self.balance += amount

    def withdraw(self, amount):
        if amount <= self.balance:
            self.balance -= amount
        else:
            raise ValueError("Insufficient balance")

    def get_balance(self):
        return self.balance



class Customer:
    def __init__(self, name, address):
        self.name = name
        self.address = address

    def get_info(self):
        return f"Name: {self.name}, Address: {self.address}"
    
    def set_info(self, name, address):
        self.name = name
        self.address = address



from setuptools import setup

setup(
    name='banking_system',
    version='1.0.4',
    author='Kunal Kumar',
    description='A simple banking management system package',
    long_description=open('README.md').read(),
    long_description_content_type="text/markdown",
    packages=['banking_system'],
    install_requires=[],  # Add dependencies if any
)



class Transaction:
    def __init__(self, sender, receiver, amount):
        self.sender = sender
        self.receiver = receiver
        self.amount = amount

    def process_transaction(self):
        try:
            self.sender.withdraw(self.amount)
            self.receiver.deposit(self.amount)
            return True
        except ValueError:
            return False
